AlwaysStop class

Always stops after the first validator.

Use when you only want the first validation result.

Implemented types

Constructors

AlwaysStop()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldStop(UIPayload? payload) bool
Returns true if validation queue should stop after this payload.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited