StopAfterSeverity class

Stops after specific severity levels.

Example:

// Stop on failure or warning, but continue on info/success
StopAfterSeverity(failure: true, warning: true)
Implemented types

Constructors

StopAfterSeverity({bool failure = false, bool warning = false, bool info = false, bool success = false})
const

Properties

failure bool
final
hashCode int
The hash code for this object.
no setterinherited
info bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
warning bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldStop(UIPayload? payload) bool
Returns true if validation queue should stop after this payload.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited