TerminationStrategy class abstract

Controls when validation should stop in a queue.

Use this to optimize validation by stopping early when a condition is met, or to ensure all validators run regardless of results.

Implementers

Constructors

TerminationStrategy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldStop(UIPayload? payload) bool
Returns true if validation queue should stop after this payload.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited