DenyPatternValidator class

Validates that string does NOT match the pattern.

Inheritance

Constructors

DenyPatternValidator(Pattern pattern)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
pattern Pattern
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(String state) bool
Returns true if the state is valid according to this validator's rules.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited