IsDifferentFromValidator<S> class

Validates that value differs from another field's value.

Example: New password must differ from old password.

Inheritance

Constructors

IsDifferentFromValidator(ValidatorTarget target)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target ValidatorTarget
finalinherited

Methods

isValid(S state) bool
Returns true if the state is valid according to this validator's rules.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited