PatternValidator class sealed
Base class for pattern-based validators (regex).
- Inheritance
- Implementers
Properties
Methods
-
isValid(
String state) → bool -
Returns true if the state is valid according to this validator's rules.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited