RequiredValidator<S> class

Validates that a value is not empty or null.

  • Strings: must not be empty
  • Iterables: must not be empty
  • Booleans: must be true (unless nullable)
  • Other types: must not be null
Inheritance

Constructors

RequiredValidator()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(S state) bool
Returns true if the state is valid according to this validator's rules.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited