StopAfterCustom class
Custom termination logic using a predicate function.
Example:
StopAfterCustom((payload) => payload is Failure || payload is Warning)
- Implemented types
Constructors
- StopAfterCustom(bool predicate(UIPayload? payload))
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldStop(
UIPayload? payload) → bool -
Returns true if validation queue should stop after this payload.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited