StopAfterFailure class
Stops immediately when a Failure is encountered.
Use when you want to stop validation as soon as any failure occurs.
Example:
Validation(
validator: Required(),
failureMsg: Failure(SimpleText('Required')),
after: StopAfterFailure(), // If this validation returns Failure, stop the queue
)
- Implemented types
Constructors
- StopAfterFailure()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldStop(
UIPayload? payload) → bool -
Returns true if validation queue should stop after this payload.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited